@@ -6,6 +6,7 @@ class CSharpUtils:
     """
     CSharp工具类
     """
+
     @staticmethod
     def convert_c_sharp_ticks_to_linux_ticks(value):
         """
@@ -39,6 +40,8 @@ class CSharpUtils:
         :return:
         """
         c_sharp_ticks1970 = 621355968000000000
+        if value < datetime.datetime(1970, 1, 3):
+            value = datetime.datetime(1970, 1, 3)
         linux_ticks = value.timestamp()
         time_zone = 28800
         linux_ticks = linux_ticks + time_zone
