@@ -267,7 +267,7 @@ class BaseBarHelper:
         lst_all_date_time_slices = []
         trading_day = begin_date
         delta = datetime.timedelta(days=1)
-        while trading_day < end_date:
+        while trading_day <= end_date:
             time_slice = TimeSlice(begin_time=datetime.timedelta(hours=0, minutes=0, seconds=0), end_time=datetime.timedelta(hours=23, minutes=59, seconds=0))
             lst_trading_time_slices = [time_slice]
             lst_time_slices = BaseBarHelper.create_time_slice(lst_trading_time_slices, 0, interval, bar_type)
