@@ -733,6 +733,9 @@ class BinaryTickStream:
         """
         if not os.path.exists(self._file_path):
             print('Append Tick, File Not Exist, Cover:{0}'.format(self._file_path))
+            record_deep_dir = os.path.dirname(self._file_path)
+            if not os.path.exists(record_deep_dir):
+                os.makedirs(record_deep_dir)
             return self.write(tick_list, start, length, quote_level)
         if os.path.getsize(self._file_path) < self.CFileHeaderLen + self.CNaturalDayLen:
             print('Append Tick, File Size Error, Cover:{0}'.format(self._file_path))
